
from django.contrib import admin
from django.urls import path, include
from chatapp.views import supporter_homepage


urlpatterns = [
    path('admin/', admin.site.urls),
    path('', include('test_1.urls')),
    path('django-chatapp/chat/supporter/', supporter_homepage),
    path('', include('chatapp.urls', namespace='chatapp')),
]
