/* *** COLOR *** */
/* *** FONTS *** */
@font-face {
  font-family: "vazir";
  src: url("../font/vazir-medium.ttf"), url("../font/vazir-medium.woff");
}
.font-vazir {
  font-family: vazir !important;
}

/* *** CONFIGS *** */
.msg__body::-webkit-scrollbar {
  background-color: transparent;
  width: 5px;
}

.msg__body::-webkit-scrollbar-thumb {
  border-radius: 5px;
  background-color: #d1d1d1;
}

.d-none {
  display: none !important;
}

.chatapp__show {
  opacity: 1 !important;
}

.chatapp__hide {
  opacity: 0 !important;
}

/* *** SOURCE CODE *** */
section.chatapp {
  box-sizing: border-box;
  z-index: 9999 !important;
  font-family: vazir !important;
  scroll-behavior: smooth !important;
  direction: rtl !important;
}
section.chatapp .chatapp__btn {
  position: fixed;
  right: 14px;
  bottom: 14px;
  cursor: pointer;
  padding: 7px 10px;
  border-radius: 10px;
  background-color: #2391eb;
}
section.chatapp .chatapp__btn + div {
  position: relative;
}
section.chatapp .chatapp__btn img {
  height: 40px;
  width: 40px;
}
section.chatapp .chatapp__btn div#alert_msg_ctx {
  position: absolute;
  top: 13px;
  left: 14px;
  height: 19px;
  width: 22px;
  border-radius: 2px;
  background-color: #fff;
  animation: blink 2s alternate infinite;
  -webkit-animation: blink 2s alternate infinite;
}
section.chatapp .chatapp__msg {
  position: fixed !important;
  right: 14px;
  border-radius: 10px;
  bottom: 87px;
  box-shadow: 0 5px 13px 3px rgba(0, 0, 0, 0.1);
  transition: all 0.5s ease;
  background-color: white;
  position: relative;
}
section.chatapp .chatapp__msg #div_spinner {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  -webkit-backdrop-filter: blur(4px);
          backdrop-filter: blur(4px);
  display: flex;
  align-items: center;
  justify-content: center;
  z-index: 20 !important;
}
section.chatapp .chatapp__msg #div_spinner .loader_spinner {
  height: 35px;
  width: 35px;
  border-radius: 50%;
  border: 7px solid #b1b1b1;
  animation: spinner 2s linear infinite;
  transition: all 0.3s;
  pointer-events: none;
  border-top: 7px solid white;
}
section.chatapp .chatapp__msg::after {
  content: "";
  height: 0;
  width: 0;
  position: absolute;
  bottom: -9px;
  right: 22px;
  border-left: 10px solid rgba(0, 0, 0, 0);
  border-right: 10px solid rgba(0, 0, 0, 0);
  border-top: 10px solid white;
}
section.chatapp .chatapp__msg .msg__header {
  background-color: #2391eb;
  border-radius: 10px 10px 0 0;
}
section.chatapp .chatapp__msg .msg__header .msg__wrapper {
  border-radius: 10px 10px 0 0;
  padding: 10px;
  background: linear-gradient(258deg, rgba(0, 0, 0, 0.3) 0%, rgba(84, 141, 177, 0) 100%) transparent;
  display: flex;
  justify-content: space-between;
  width: 375px;
}
section.chatapp .chatapp__msg .msg__header .msg__wrapper .header__info {
  display: flex;
}
section.chatapp .chatapp__msg .msg__header .msg__wrapper .header__info img {
  height: 45px;
  width: 45px;
  border-radius: 50%;
}
section.chatapp .chatapp__msg .msg__header .msg__wrapper .header__info div {
  display: flex;
  flex-direction: column;
  color: #fff;
  margin: 0 10px;
  position: relative;
  min-width: 140px;
}
section.chatapp .chatapp__msg .msg__header .msg__wrapper .header__info div span:nth-child(1) {
  font-size: 20px;
}
section.chatapp .chatapp__msg .msg__header .msg__wrapper .header__info div span:nth-child(2) {
  font-size: 9pt;
  position: absolute;
  right: 0;
  bottom: 0px;
  display: flex;
}
section.chatapp .chatapp__msg .msg__header .msg__wrapper .header__options button {
  background-color: transparent;
  border: none;
  color: #fff;
  outline: none;
  cursor: pointer;
  font-size: 20px;
  margin-top: 8px;
  transition: all 0.3s;
}
section.chatapp .chatapp__msg .msg__header .msg__wrapper .header__options button.bottom__msgbox img {
  height: 22px !important;
  width: 22px !important;
  margin-bottom: 2px;
}
section.chatapp .chatapp__msg .msg__header .msg__wrapper .header__options button.close__msgbox img {
  height: 26px !important;
  width: 26px !important;
}
section.chatapp .chatapp__msg .msgdel__right {
  float: right !important;
}
section.chatapp .chatapp__msg .msgdel__left {
  float: left !important;
}
section.chatapp .chatapp__msg .msg__body {
  background-color: #fff;
  padding: 10px 15px;
  overflow-y: auto;
  -webkit-overflow-scrolling: touch;
  height: 320px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper .deleted_msg {
  background-color: #d1d1d1 !important;
  color: white !important;
  padding: 3px 4px;
  font-size: 13px;
  border-radius: 5px;
  margin-bottom: 5px;
  width: 175px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper .deleted_msg img {
  height: 12px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper {
  width: 100%;
  height: auto;
  position: relative;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper ul.msg-menu-bar {
  position: absolute;
  top: -13px;
  padding: 5px;
  background-color: rgb(0, 0, 0);
  z-index: 5;
  list-style: none;
  color: #d1d1d1;
  width: 100px;
  font-size: 12px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper ul.msg-menu-bar li {
  cursor: pointer;
  padding: 3px 5px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper ul.msg-menu-bar li img {
  height: 13px;
  margin-bottom: -4px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper ul.msg-menu-bar li:hover {
  color: white;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper ul.msg-menu-bar--right {
  right: 0 !important;
  left: unset !important;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper ul.msg-menu-bar--left {
  left: 0 !important;
  right: unset !important;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper:hover .reply_one_msg {
  opacity: 1;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg {
  padding: 7px 10px;
  margin-bottom: 5px;
  max-width: 240px;
  min-width: 100px;
  text-align: right;
  color: #fff;
  position: relative;
  transition: background-color 0.3s linear;
  z-index: 2;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg p {
  margin: 0px !important;
  word-break: break-word;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg p.msg__replied {
  padding: 3px 5px;
  border-right: 2px solid #fff;
  margin-bottom: 7px !important;
  border-radius: 4px 0 0 4px;
  display: flex;
  flex-direction: column;
  cursor: pointer;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg p.msg__replied span {
  font-size: 9pt;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg p.msg__replied--right {
  background-color: #39a2f9;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg p.msg__replied--left {
  background-color: #c5c5c5;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg div.msg__info {
  margin-top: 5px;
  margin-bottom: -5px;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg div.msg__info__clock {
  font-size: 9pt;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg div.msg__info__edited {
  font-size: 9pt;
  padding: 0 7px;
  margin-top: -3px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg div.msg__info__status img {
  height: 14px;
  width: 16px;
  margin-left: 5px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg__left {
  float: left;
  border-radius: 12px;
  background-color: #d1d1d1;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg__left::after {
  content: "";
  position: absolute;
  bottom: 9px;
  left: -8px;
  width: 0;
  height: 0;
  border-top: 8px solid transparent;
  border-bottom: 0px solid transparent;
  border-right: 8px solid #d1d1d1;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg__left div.msg__info__clock {
  padding-bottom: 4px !important;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg__right {
  float: right;
  border-radius: 12px;
  background-color: #2391eb;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .msg__right::after {
  content: "";
  position: absolute;
  bottom: 9px;
  right: -8px;
  width: 0;
  height: 0;
  border-top: 8px solid transparent;
  border-bottom: 0px solid transparent;
  border-left: 8px solid #2391eb;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .reply_one_msg {
  color: #d1d1d1;
  font-size: 10pt;
  opacity: 0;
  line-height: 11px;
  z-index: 1;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .reply_one_msg--right {
  transform: translate(-5px, 7px);
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .reply_one_msg--left {
  text-align: left;
  transform: translate(5px, 7px);
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .reply_one_msg span {
  cursor: pointer;
  transition: all 0.2s;
  margin: 0 !important;
  padding: 4px 0;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper div.one_msg_wrapper .reply_one_msg span:hover {
  color: #9e9e9e;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .all__msg__wrapper .clearfix {
  clear: both;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game #restart__game {
  border: none;
  outline: none;
  font-family: vazir;
  padding: 5px 15px;
  border-radius: 5px;
  cursor: pointer;
  background-color: #ececec;
  margin-bottom: 15px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game #restart__game:active {
  transform: translateY(-1px);
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game #score__game {
  display: flex;
  justify-content: center;
  margin-bottom: 20px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game #score__game div {
  margin: 0 15px;
  display: flex;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game #score__game div span:nth-child(1) {
  color: #d1d1d1;
  padding-left: 3px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .btns__wrapper {
  width: 208px;
  margin: auto;
  position: relative;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .btns__wrapper #bg__glass {
  background-color: transparent;
  position: absolute;
  inset: 0;
  cursor: not-allowed !important;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .btns__wrapper__btn {
  display: flex;
  background-color: #2391eb;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .btns__wrapper__btn .btn_game {
  padding: 0px;
  height: 65px;
  width: 68px;
  border: none;
  outline: none;
  background-color: #fff;
  display: flex;
  justify-content: center;
  align-items: center;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .btns__wrapper__btn .btn_game img {
  height: 50%;
  height: 50%;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .btns__wrapper__btn .m2px_l {
  margin-left: 2px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .btns__wrapper__btn .m2px_b {
  margin-bottom: 2px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .btns__wrapper__btn .disable_btn {
  cursor: not-allowed !important;
  pointer-events: none;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game #game_alert_msg {
  color: white;
  padding: 8px 7px;
  border-radius: 7px;
  max-width: 1100px;
  margin: 20px auto;
  background-color: #2391eb;
  font-size: 11pt;
  text-align: center;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .game_alert_msg_win {
  background-color: #d1d1d1 !important;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .tictoctoe__game .game_alert_msg_lose {
  background-color: #2391eb !important;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form {
  width: 250px;
  margin: 20px auto;
  border-radius: 8px;
  box-shadow: 0 0 13px 3px rgba(0, 0, 0, 0.1);
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form .chatform__header {
  border-radius: 8px 8px 0px 0px;
  background-color: #2391eb;
  padding: 8px;
  color: #fff;
  font-size: 9pt;
  text-align: start;
  margin-bottom: 10px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form {
  padding: 1rem;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form div.chatapp_formcontrol {
  position: relative;
  margin-bottom: 23px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form div.chatapp_formcontrol input {
  font-family: vazir;
  width: 92%;
  padding: 7px;
  font-size: 13pt;
  color: #2391eb;
  border: 1px solid #d1d1d1;
  border-radius: 5px;
  outline: none;
  background: #fff !important;
  transition: all 0.3s linear;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form div.chatapp_formcontrol input:focus {
  border-color: rgb(132.5, 132.5, 132.5);
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form div.chatapp_formcontrol input:focus ~ label {
  color: rgb(132.5, 132.5, 132.5);
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form div.chatapp_formcontrol label {
  position: absolute;
  pointer-events: none;
  top: -15px;
  right: 10px;
  color: #d1d1d1;
  font-size: 13px;
  padding: 0 7px;
  background-color: white;
  transition: all 0.3s linear;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form div.chatapp_formcontrol p.form_error {
  color: red;
  font-size: 12px;
  margin: 0px;
  margin-top: 5px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form .mbnone__chatapp {
  margin-bottom: unset !important;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form .chatapp_button {
  width: 100%;
  display: flex;
  justify-content: end;
  margin-top: 13px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .chatapp__form form .chatapp_button button {
  font-family: vazir;
  border: none;
  outline: none;
  padding: 5px 25px;
  cursor: pointer;
  border-radius: 5px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .btn_last_msg {
  position: absolute;
  left: 20px;
  bottom: 60px;
  z-index: 9999;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .btn_last_msg button {
  cursor: pointer;
  outline: none;
  border: none;
  border-radius: 50%;
  background-color: rgba(0, 0, 0, 0.3);
  position: relative;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .btn_last_msg button img {
  height: 35px;
  width: 35px;
  padding: 5px 3px;
  padding-top: 8px;
}
section.chatapp .chatapp__msg .msg__body .body__wrapper .btn_last_msg button div.unreadmsg_counter {
  position: absolute;
  right: -2px;
  top: -2px;
  padding: 3px 7px;
  background-color: #2391eb;
  border-radius: 50%;
  font-size: 10pt;
  color: #fff;
}
section.chatapp .chatapp__msg .body__inputs {
  padding: 0px 10px;
  padding-top: 4px !important;
  background-color: white;
  border-radius: 0 0 10px 10px;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper {
  background-color: #ececec;
  border-radius: 25px;
  display: flex;
  position: relative;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper input {
  flex: auto;
  font-family: vazir !important;
  outline: none;
  border: none;
  background-color: #ececec;
  padding: 10px 15px;
  border-radius: 25px;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper .reply_msg_wrapper {
  position: absolute;
  bottom: 44px;
  border-radius: 7px;
  right: 0px;
  background-color: #ececec;
  padding: 5px 10px;
  z-index: 9999;
  width: 70%;
  display: flex;
  justify-content: space-between;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper .reply_msg_wrapper div {
  order: 1;
  display: flex;
  flex-direction: column;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper .reply_msg_wrapper div p {
  margin: 0;
  color: rgb(94, 94, 94);
  font-size: 9pt;
  padding: 0 5px;
  border-right: 2px solid #fff;
  height: 20px;
  overflow: hidden;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper .reply_msg_wrapper button.close_replybar {
  order: 2;
  background-color: transparent !important;
  color: rgb(94, 94, 94);
  border: none;
  outline: none;
  font-size: 20px;
  cursor: pointer;
  padding: 0 10px 10px 0;
  height: 100%;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper .reply_msg_wrapper button.close_replybar:hover {
  color: black;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper .emoji_wrapper {
  position: absolute;
  bottom: 44px;
  border-radius: 7px;
  right: 0px;
  background-color: #ececec;
  padding: 5px 10px;
  z-index: 9999;
  width: 70%;
  height: 100px;
  overflow-y: scroll;
  display: flex;
  justify-content: space-between;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper .emoji_wrapper div.emoji_box {
  order: 1;
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper .emoji_wrapper div.emoji_box div.emoji_item {
  flex: 1;
  cursor: pointer;
  font-size: 18px;
  padding: 4px;
  max-width: 25px;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper button.show_game {
  outline: none;
  background-color: transparent;
  border: none;
  margin-right: 3px;
  padding: 6px 10px;
  cursor: pointer;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper button.show_game img {
  height: 26px;
  width: 28px;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper button.show_emoji {
  outline: none;
  background-color: transparent;
  border: none;
  margin-right: 3px;
  padding: 6px 2px;
  cursor: pointer;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper button.show_emoji img {
  height: 26px;
  width: 28px;
  margin-bottom: -4px;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper button[type=submit] {
  outline: none;
  background-color: #2391eb;
  border: none;
  margin-right: 3px;
  border-radius: 25px;
  padding: 6px 20px;
  cursor: pointer;
}
section.chatapp .chatapp__msg .body__inputs form div.forminput_wrapper button[type=submit] img {
  height: 20px;
  width: 21px;
}
section.chatapp .chatapp__msg .body__inputs .goback_chat_btn {
  text-align: center;
  padding: 4px;
  cursor: pointer;
  transition: all 0.3s;
}
section.chatapp .chatapp__msg .body__inputs .goback_chat_btn:hover {
  color: #2391eb;
}
section.chatapp .chatapp__msg .body__inputs .goback_chat_btn .new_msg_shower {
  background-color: #2391eb;
  color: white;
  width: 56px;
  font-size: 12px;
  border-radius: 5px;
  padding: 4px;
  display: flex;
  align-items: center;
  justify-content: center;
  float: left;
  margin-bottom: 10px;
}
section.chatapp .chatapp__msg .body__inputs .goback_chat_btn .new_msg_shower img {
  height: 20px;
  margin-bottom: -5px;
}
section.chatapp .chatapp__msg .body__inputs .goback_chat_btn .new_msg_shower div {
  flex: 1;
}

section.chatapp__ltr {
  direction: ltr !important;
}
section.chatapp__ltr .chatapp__btn {
  left: 14px;
  right: unset !important;
}
section.chatapp__ltr .chatapp__msg {
  left: 14px;
  right: unset !important;
  border-radius: 10px;
  bottom: 87px;
  box-shadow: 0 0 13px 3px rgba(0, 0, 0, 0.1);
}
section.chatapp__ltr .chatapp__msg::after {
  right: unset !important;
  left: 22px;
}
section.chatapp__ltr .msg__info__status img {
  margin-right: 5px;
  margin-left: unset !important;
}
section.chatapp__ltr .msg__header .msg__wrapper .header__info div span:nth-child(2) {
  right: unset !important;
  left: 0;
}
section.chatapp__ltr .chatapp__msg .body__inputs form div button {
  margin-right: unset !important;
  margin-left: 3px;
}
section.chatapp__ltr .chatapp__msg .msg__body .body__wrapper .chatapp__form form div.chatapp_formcontrol label {
  right: unset !important;
  left: 10px;
}
section.chatapp__ltr .m2px_l {
  margin-left: unset !important;
  margin-right: 2px;
}
section.chatapp__ltr .msg__body .body__wrapper .msg {
  text-align: left !important;
}
section.chatapp__ltr .msg__body .body__wrapper .msg p.msg__replied {
  border-right: unset !important;
  border-left: 2px solid #fff;
  border-radius: 0 4px 4px 0 !important;
}
section.chatapp__ltr .chatapp__msg .msg__header .msg__wrapper {
  background: linear-gradient(258deg, rgba(84, 141, 177, 0) 0%, rgba(0, 0, 0, 0.3) 100%) transparent !important;
}
section.chatapp__ltr .body__inputs .btn_last_msg {
  left: unset !important;
  right: 15px;
}
section.chatapp__ltr .body__inputs form div.forminput_wrapper .reply_msg_wrapper {
  left: 0px;
  right: unset !important;
}
section.chatapp__ltr .body__inputs form div.forminput_wrapper .reply_msg_wrapper div p {
  border-left: 2px solid #fff !important;
  border-right: unset !important;
}
section.chatapp__ltr .body__inputs form div.forminput_wrapper .emoji_wrapper {
  left: 0px;
  right: unset !important;
}
section.chatapp__ltr .reply_one_msg--right {
  float: right !important;
}
section.chatapp__ltr .body__wrapper .msg div.msg__info__edited {
  margin-top: unset !important;
}

/* *** ANIMATIONS *** */
@keyframes blink {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@keyframes spinner {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}
/* *** Media queries *** */
@media screen and (min-width: 1001px) {
  .chatapp__msg .msg__header .msg__wrapper {
    width: 375px !important;
  }
}
@media screen and (max-width: 1000px) {
  .chatapp__msg .msg__header .msg__wrapper .header__info div span:nth-child(1) {
    font-size: 12pt !important;
  }
  .chatapp__msg .msg__header .msg__wrapper .header__info div span:nth-child(2) {
    font-size: 9pt !important;
  }
}/*# sourceMappingURL=client.css.map */